@@ -19,7 +19,7 @@ class App(Base):
 
   def source(self, name=None, matches=None, options={}, emits=None, end_cycle_policy="null_emit", prepare=None, begin_cycle=None, next_tuple=None):
     op = OperationHandler(self, Stream)
-    streams = op.build_multilang_operation("source", name, matches, options, emits, end_cycle_policy, begin_cycle, next_tuple)\
+    streams = op.build_multilang_operation("source", name, matches, options, emits, end_cycle_policy, prepare, begin_cycle, next_tuple)\
                        .add_operation_properties_to_info("name", "type")\
                        .add_optional_operation_properties_to_info("relation", "matches", "end_cycle_policy")\
                        .handle_operation()\
