@@ -298,9 +298,10 @@ class Helper:
     self.check_field_format("outputs", pp, node._name, node._columns)
 
   @classmethod
-  def check_loop_back(self, node_name, nodes):
-    ee = "Error in \"loop_back\": \n\t "
+  def check_loop_back(self, stream, node_name, nodes):
+    ee = "Error in \"loop_back\" to \"%s\": \n\t "%(node_name)
 
+    previous_node_name = stream._previous_node_name
     found = False
     for node in nodes:
       if node._name == node_name:
@@ -308,6 +309,10 @@ class Helper:
         if node._type == "source":
           msg = ee+"Cannot loop back to source node \"%s\"!"%(node_name)
           self.print_error(msg)
+      if node._name == previous_node_name:
+        if len(node._emits) < 2:
+          msg = ee+"The preceding operation does not emit multiple streams. Please make sure that it emits one stream for the loop back and another stream for downstream operations."
+          self.print_error(msg)
     if not found:
       msg = ee+"The specified loop-back node \"%s\" was not found in the operations preceding it."%(node_name)
       self.print_error(msg)
